@@ -30,10 +30,7 @@
 class WP60Header : public WP6Header
 {
  public:
-	WP60Header(GsfInput * input, guint32 documentOffset, guint8 productType, guint8 fileType, guint8 majorVersion, guint8 minorVersion, guint16 documentEncryption);
+	WP60Header(WPXInputStream * input, uint32_t documentOffset, uint8_t productType, uint8_t fileType, uint8_t majorVersion, uint8_t minorVersion, uint16_t documentEncryption);
 	virtual ~WP60Header();
-		
- private:
-
 };
 #endif /* _WP60HEADER_H  */
