@@ -1,4 +1,4 @@
-/* libwpd2
+/* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
  * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
  *  
@@ -30,12 +30,12 @@
 class WP61Header : public WP6Header
 {
  public:
-	WP61Header(GsfInput * input);
+	WP61Header(WPXInputStream * input, uint32_t documentOffset, uint8_t productType, uint8_t fileType, uint8_t majorVersion, uint8_t minorVersion, uint16_t documentEncryption);
 	virtual ~WP61Header();
 	
-	const guint32 getDocumentSize() const { return m_documentSize; }
+	const uint32_t getDocumentSize() const { return m_documentSize; }
 		
  private:
-	guint32 m_documentSize;
+	uint32_t m_documentSize;
 };
 #endif /* _WP61HEADER_H  */
