@@ -23,12 +23,11 @@
  * Corel Corporation or Corel Corporation Limited."
  */
 #include <string.h>
-#include <gsf/gsf-input-memory.h>
 
 #include "WP6ExtendedDocumentSummaryPacket.h"
 #include "libwpd_internal.h"
 
-WP6ExtendedDocumentSummaryPacket::WP6ExtendedDocumentSummaryPacket(GsfInput *input, int id, guint32 dataOffset, guint32 dataSize) 
+WP6ExtendedDocumentSummaryPacket::WP6ExtendedDocumentSummaryPacket(WPXInputStream *input, int id, uint32_t dataOffset, uint32_t dataSize) 
 	: WP6PrefixDataPacket(input),
 	  m_dataSize(dataSize)
 {	
@@ -37,77 +36,76 @@ WP6ExtendedDocumentSummaryPacket::WP6ExtendedDocumentSummaryPacket(GsfInput *inp
 
 WP6ExtendedDocumentSummaryPacket::~WP6ExtendedDocumentSummaryPacket()
 {
-	g_object_unref(G_OBJECT(m_stream));
+	DELETEP(m_stream);
 }
 
-void WP6ExtendedDocumentSummaryPacket::_readContents(GsfInput *input)
+void WP6ExtendedDocumentSummaryPacket::_readContents(WPXInputStream *input)
 {
-	// we have to use glib's allocation function because libgsf disposes of the data
-	guint8 *streamData = (guint8 *)g_malloc(sizeof(guint8)*m_dataSize); 
+	uint8_t *streamData = new uint8_t[m_dataSize];
 	for(int i=0; i<m_dataSize; i++)
-		streamData[i] = gsf_le_read_guint8(input);
-                   
-	m_stream = GSF_INPUT(gsf_input_memory_new(streamData, m_dataSize, TRUE));
+		streamData[i] = readU8(input);
+	
+	m_stream = new WPXMemoryInputStream(streamData, m_dataSize);
 }
 
 void WP6ExtendedDocumentSummaryPacket::parse(WP6HLListener *listener) const
 {
 	int k=0;
-	guint16 groupLength = 0;
+	uint16_t groupLength = 0;
 
 	for (int i=0; i < m_dataSize; i+=groupLength)
 	{
-		groupLength = gsf_le_read_guint16(m_stream);
-		guint16 tagID = gsf_le_read_guint16(m_stream);
-		guint16 flags = gsf_le_read_guint16(m_stream);
+		groupLength = readU16(m_stream);
+		uint16_t tagID = readU16(m_stream);
+		uint16_t flags = readU16(m_stream);
 
-		UCSString name;
-		for (guint16 wpChar = gsf_le_read_guint16(m_stream);
+		WPXString name;
+		for (uint16_t wpChar = readU16(m_stream);
 		     wpChar != 0; 
-		     wpChar = gsf_le_read_guint16(m_stream))
+		     wpChar = readU16(m_stream))
 		{
-			guint8 character = (wpChar & 0xFF);
-			guint8 characterSet = (wpChar & 0xFF00) >> 8;
-			const guint16 *chars;
+			uint8_t character = (wpChar & 0xFF);
+			uint8_t characterSet = (wpChar & 0xFF00) >> 8;
+			const uint16_t *chars;
 			int len;
-			len = extendedCharacterToUCS2(character,
+			len = extendedCharacterWP6ToUCS2(character,
 						      characterSet, &chars);
 			for (int j = 0; j < len; j++)
-				name.append(chars[j]);
+				appendUCS4(name, (uint32_t)chars[j]);
 		} 
 		
 		if (tagID == WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_CREATION_DATE ||
 		    tagID == WP6_INDEX_HEADER_EXTENDED_DOCUMENT_SUMMARY_DATE_COMPLETED)
 		{
-			guint16 year = gsf_le_read_guint16(m_stream);
-			guint8 month = gsf_le_read_guint8(m_stream);
-			guint8 day = gsf_le_read_guint8(m_stream);
-			guint8 hour = gsf_le_read_guint8(m_stream);
-			guint8 minute = gsf_le_read_guint8(m_stream);
-			guint8 second = gsf_le_read_guint8(m_stream);
-			guint8 dayOfWeek = gsf_le_read_guint8(m_stream);
-			guint8 timeZone = gsf_le_read_guint8(m_stream);
-			guint8 unused = gsf_le_read_guint8(m_stream);
+			uint16_t year = readU16(m_stream);
+			uint8_t month = readU8(m_stream);
+			uint8_t day = readU8(m_stream);
+			uint8_t hour = readU8(m_stream);
+			uint8_t minute = readU8(m_stream);
+			uint8_t second = readU8(m_stream);
+			uint8_t dayOfWeek = readU8(m_stream);
+			uint8_t timeZone = readU8(m_stream);
+			uint8_t unused = readU8(m_stream);
 			listener->setDate(year, month, day, hour, minute, second, dayOfWeek, timeZone, unused);
 		}
 		else
 		{
-			UCSString data;
-			for (guint16 wpChar = gsf_le_read_guint16(m_stream);
+			WPXString data;
+			for (uint16_t wpChar = readU16(m_stream);
 			     wpChar != 0; 
-			     wpChar = gsf_le_read_guint16(m_stream))
+			     wpChar = readU16(m_stream))
 			{				
-			guint8 character = (wpChar & 0xFF);
-			guint8 characterSet = (wpChar & 0xFF00) >> 8;
-			const guint16 *chars;
+			uint8_t character = (wpChar & 0xFF);
+			uint8_t characterSet = (wpChar & 0xFF00) >> 8;
+			const uint16_t *chars;
 			int len;
-			len = extendedCharacterToUCS2(character,
+			len = extendedCharacterWP6ToUCS2(character,
 						      characterSet, &chars);
 			for (int j = 0; j < len; j++)
-				data.append(chars[j]);
+				appendUCS4(data, (uint32_t)chars[j]);
 			} 
 			listener->setExtendedInformation(tagID, data);
 		}
-		WPD_CHECK_FILE_SEEK_ERROR(gsf_input_seek(m_stream, (i+groupLength), G_SEEK_SET));
+		m_stream->seek((i+groupLength), WPX_SEEK_SET);
 	}
 }
