@@ -27,13 +27,13 @@
 #include "WP6FontDescriptorPacket.h"
 #include "libwpd_internal.h"
 
-const char *FONT_WEIGHT_STRINGS[] = { "Bold", "Demi", "Extended", 
-				      "Extra", "Headline", "Light", "Medium", 
-				      "Normal", "Regular", "Standaard", "Standard" };
+const char *FONT_WEIGHT_STRINGS[] = { "Bold", "Demi", "Extended", "Extra", 
+				      "Headline", "Light", "Medium", "Normal", 
+				      "Regular", "Standaard", "Standard" };
 const char * USELESS_WP_POSTFIX = "-WP";
 #define countElements(a) ((sizeof(a) / sizeof(a[0])))
 
-WP6FontDescriptorPacket::WP6FontDescriptorPacket(GsfInput *input, int id, guint32 dataOffset, guint32 dataSize) 
+WP6FontDescriptorPacket::WP6FontDescriptorPacket(WPXInputStream *input, int id, uint32_t dataOffset, uint32_t dataSize) 
 	: WP6PrefixDataPacket(input)
 {
 	_read(input, dataOffset, dataSize);
@@ -44,58 +44,58 @@ WP6FontDescriptorPacket::~WP6FontDescriptorPacket()
 	delete [] m_fontName;
 }
 
-void WP6FontDescriptorPacket::_readContents(GsfInput *input)
+void WP6FontDescriptorPacket::_readContents(WPXInputStream *input)
 {
    // short sized characteristics
-   m_characterWidth = gsf_le_read_guint16(input);
-   m_ascenderHeight = gsf_le_read_guint16(input);
-   m_xHeight = gsf_le_read_guint16(input);
-   m_descenderHeight = gsf_le_read_guint16(input);
-   m_italicsAdjust = gsf_le_read_guint16(input);
+   m_characterWidth = readU16(input);
+   m_ascenderHeight = readU16(input);
+   m_xHeight = readU16(input);
+   m_descenderHeight = readU16(input);
+   m_italicsAdjust = readU16(input);
    // byte sized characteristics
-   m_primaryFamilyMemberId = gsf_le_read_guint8(input);
-   m_primaryFamilyId = gsf_le_read_guint8(input);
-   m_scriptingSystem = gsf_le_read_guint8(input);
-   m_primaryCharacterSet = gsf_le_read_guint8(input);
-   m_width = gsf_le_read_guint8(input);
-   m_weight = gsf_le_read_guint8(input);
-   m_attributes = gsf_le_read_guint8(input);
-   m_generalCharacteristics = gsf_le_read_guint8(input);
-   m_classification = gsf_le_read_guint8(input);
-   m_fill = gsf_le_read_guint8(input);
-   m_fontType = gsf_le_read_guint8(input);
-   m_fontSourceFileType = gsf_le_read_guint8(input);
+   m_primaryFamilyMemberId = readU8(input);
+   m_primaryFamilyId = readU8(input);
+   m_scriptingSystem = readU8(input);
+   m_primaryCharacterSet = readU8(input);
+   m_width = readU8(input);
+   m_weight = readU8(input);
+   m_attributes = readU8(input);
+   m_generalCharacteristics = readU8(input);
+   m_classification = readU8(input);
+   m_fill = readU8(input);
+   m_fontType = readU8(input);
+   m_fontSourceFileType = readU8(input);
 
-   m_fontNameLength = gsf_le_read_guint16(input); 
+   m_fontNameLength = readU16(input); 
 
    // TODO: re-do sanity checking
    //if(m_fontNameLength < WP_FONT_NAME_MAX_LENGTH)
    //{	
    if (m_fontNameLength == 0) 
 	   {
-		   m_fontName = new gchar[1];
+		   m_fontName = new char[1];
 		   m_fontName[0]='\0';
 	   }
    
    else 
 	   {
-		   m_fontName = new gchar[m_fontNameLength];
+		   m_fontName = new char[m_fontNameLength];
 
-		   guint16 tempLength=0;
+		   uint16_t tempLength=0;
 		   int numTokens=0;
 		   int lastTokenPosition=0;
-		   for (guint16 i=0; i<(m_fontNameLength/2); i++) 
+		   for (uint16_t i=0; i<(m_fontNameLength/2); i++) 
 		   {
-			   guint8 characterSet;
-			   guint8 character;
+			   uint8_t characterSet;
+			   uint8_t character;
 			   int len;
-			   const guint16 *chars;
-			   guint16 charWord = gsf_le_read_guint16(input);
+			   const uint16_t *chars;
+			   uint16_t charWord = readU16(input);
 
 			   characterSet = (charWord & 0xFF00) >> 8;
 			   character = (charWord & 0xFF);
 			   
-			   len = extendedCharacterToUCS2(character, characterSet, &chars);
+			   len = extendedCharacterWP6ToUCS2(character, characterSet, &chars);
 			   /* We are only using ascii characters here, and
 			    * if we have more than one character, that's
 			    * going to be an international character, so
@@ -110,7 +110,7 @@ void WP6FontDescriptorPacket::_readContents(GsfInput *input)
 				   lastTokenPosition=tempLength;
 			   }
 			   else if (chars[0] != 0x00 && chars[0] < 0x7F) {
-				   m_fontName[tempLength]=(gchar) chars[0];
+				   m_fontName[tempLength]=(char) chars[0];
 				   tempLength++;
 			   }
 		   }
